# This file is part of the Django-fatpages project, and thus being
# redistributed under the same terms, ie.: the GPL v3 license.
# See LICENSE files for more details
"""
fatpages unittests
"""
from django.test import TestCase
from django.test.client import Client
from fatpages.models import FatPage
from templatetags.fatpages import render
from fatpages import settings

class FatpageTestCase(TestCase):
    fixtures = ['test_pages']

    def setUp(self):
        self.client = Client()
        self.homepage = FatPage.objects.get(url='/')
        self.brokenabout = FatPage.objects.get(url='/about')
        self.linebreaks = FatPage.objects.get(url='/linebreaks/')
        self.markups = settings.AVAILABLE_MARKUPS
        # Partially Borrowed from
        # http://code.djangoproject.com/browser/django/trunk/tests/othertests/markup.py?rev=3420
        self.markup_test_cases = (
            ('textile',
            """Paragraph 1\n\nParagraph 2 with "quotes" and @code@""",
            """<p>Paragraph 1</p>\n\n<p>Paragraph 2 with &#8220;quotes&#8221; and <code>code</code></p>"""),
            ('markdown',
            """Paragraph 1\n\n## An h2""",
            """<p>Paragraph 1\n</p>\n\n<h2> An h2</h2>"""),
            ('restructuredtext',
            """Paragraph 1\n\nParagraph 2 with a link_\n\n.. _link: http://www.example.com/""",
            """<p>Paragraph 1</p>\n<p>Paragraph 2 with a <a class="reference" href="http://www.example.com/">link</a></p>"""),
        )


    def testAbsoluteUrl(self):
        self.assertEquals(self.brokenabout.get_absolute_url(), '/about/')
        for page in FatPage.objects.all():
            self.assert_(page.get_absolute_url().endswith('/'))

    def testRenderingEngine(self):
        # this test is optional, but let's save it anyway.
        self.assertEquals(render(self.homepage), "<p>This is my <strong>home</strong> page<br />in pure HTML.</p>")
        self.assertEquals(render(self.linebreaks), "<p>this page.</p>\n\n<p>I am<br />testing line breaks.</p>")

        for markup, content, output in self.markup_test_cases:
            if markup in dict(self.markups):
                page = FatPage(url="/test/", title="test", content=content, markup=markup)
                self.assertEquals(render(page).strip(), output)

    def testUnavailableRenderings(self):
        # TODO: Must return the content + a warning message
        invalid_fatpage = FatPage(url='/invalid/', title="Invalid",
            content="""Paragraph 1\n\nParagraph 2 with "quotes" and @code@""", markup="invalid")
        expected_content = '<p class="error">"%s" is an unavailable markup</p>%s' % (
            invalid_fatpage.markup,
            invalid_fatpage.content,
        )
        self.assertEquals(render(invalid_fatpage).strip(), expected_content)

# EOF
